@@ -5,18 +5,13 @@ import click
 import redis
 
 js_edit_opts = {"require_save": False, "extension": ".js"}
-txt_edit_opts = {"require_save": False, "extension": ".txt"}
 
 
-def add_json_to_redis(cl, edited_doc, st=False, zst=False):
+def multiple_add(cl, edited_doc):
     data = json.loads(edited_doc)
     with cl.pipeline() as pipe:
         for key, value in data.items():
-            if st:
-                pipe.sadd(key, *value)
-            elif zst:
-                pipe.zadd(key, {value[0]: value[1]})
-            elif isinstance(value, dict):
+            if isinstance(value, dict):
                 pipe.hmset(key, value)
             elif isinstance(value, list):
                 pipe.rpush(key, *value)
@@ -26,23 +21,25 @@ def add_json_to_redis(cl, edited_doc, st=False, zst=False):
 
 
 def add_any_key_type(cl, edited_doc, key_type, key):
-    data = edited_doc.split()
+    data = json.loads(edited_doc)
     if key_type == "string":
-        cl.set(key, "".join(data))
+        cl.set(key, data)
     elif key_type == "bits":
-        if len(data) != 2:
-            raise click.ClickException("Bits data can contain only offset and value")
-        else:
-            cl.setbit(key, data[0], data[1])
+        cl.setbit(key, data['offset'], data['value'])
     elif key_type == "list":
         cl.rpush(key, *data)
+    elif key_type == 'hash':
+        cl.hmset(key, data)
     elif key_type == "set":
         cl.sadd(key, *data)
-    elif key_type == "sorted_set":
-        dct = {}
-        for i in range(1, len(data), 2):
-            dct[data[i - 1]] = data[i]
-        cl.zadd(key, dct)
+    elif key_type == "zset":
+        try:
+            cl.zadd(key, data)
+        except AttributeError:
+            dct = {}
+            for item in data:
+                dct[item[0]] = item[1]
+            cl.zadd(key, dct)
     elif key_type == "hyll":
         cl.pfadd(key, *data)
 
@@ -137,10 +134,10 @@ def show_db(ctx, key, pattern):
 @click.option("-l", "--lst/--no-lst", default=False, help="List type key")
 @click.option("-h", "--hsh/--no-hsh", default=False, help="Hash type key")
 @click.option("-s", "--st/--no-st", default=False, help="Set type key")
-@click.option("-z", "--sset/--no-sset", default=False, help="Sorted set type key")
+@click.option("-z", "--zst/--no-zst", default=False, help="Sorted set type key")
 @click.option("-e", "--hyll/--no-hyll", default=False, help="HyperLogLog type key")
 @click.pass_context
-def add_key(ctx, key, bits, lst, hsh, st, sset, hyll):
+def add_key(ctx, key, bits, lst, hsh, st, zst, hyll):
     """Add key to db. Don't support streams and geo"""
     cl = ctx.obj["RedisClient"]
     key_type = None
@@ -148,8 +145,8 @@ def add_key(ctx, key, bits, lst, hsh, st, sset, hyll):
         "bits": bits,
         "list": lst,
         "set": st,
-        "hsh": hsh,
-        "sorted_set": sset,
+        "hash": hsh,
+        "zset": zst,
         "hyll": hyll,
     }
     for ke, value in types_dict.items():
@@ -160,65 +157,70 @@ def add_key(ctx, key, bits, lst, hsh, st, sset, hyll):
                 raise click.ClickException("Only one key type can be set")
     if key_type is None:
         key_type = "string"
-    # open txt-editor
-    if key_type == "hsh":
-        new_doc = {"key1": "value1", "key2": "value2"}
-        edited_doc = click.edit(json.dumps(new_doc, indent=4), **js_edit_opts)
-        if edited_doc:
-            try:
-                add_json_to_redis(cl, json.dumps({key: json.loads(edited_doc)}))
-            except Exception as ex:
-                print("Key was not added: ", ex)
-    # open json-editor.
-    elif key_type:
-        new_doc = "value"
-        edited_doc = click.edit(new_doc, **txt_edit_opts)
-        if edited_doc:
-            try:
-                add_any_key_type(cl, edited_doc, key_type, key)
-            except Exception as ex:
-                print("Key was not added: ", ex)
+    if key_type == "string":
+        new_doc = 'value'
+    elif key_type == "list":
+        new_doc = ["value1", "value2", "value3"]
+    elif key_type == 'set':
+        new_doc = ["value1", "value2", "value3"]
+    elif key_type == 'bits':
+        new_doc = {"offset": 1, "value": 1}
+    elif key_type == 'zset':
+        new_doc = {'key1': 1.1, 'key2': 1.2}
+    elif key_type == 'hash':
+        new_doc = {'key1': 'value1', 'key2': 'value2'}
+    elif key_type == "hyll":
+        new_doc = ['1', '2', '3', '4']
     else:
         print(key_type)
         raise click.ClickException("Key type should be set")
-
-
-@cli.command()
-@click.pass_context
-def add_data(ctx):
-    """Add json-format data to db"""
-    cl = ctx.obj["RedisClient"]
-    new_doc = {"key1": "value1", "key2": "value2"}
     edited_doc = click.edit(json.dumps(new_doc, indent=4), **js_edit_opts)
     if edited_doc:
         try:
-            add_json_to_redis(cl, edited_doc)
+            add_any_key_type(cl, edited_doc, key_type, key)
         except Exception as ex:
             print("Key was not added: ", ex)
 
 
 @cli.command()
-@click.option("-k", "--key", help="Document key.")
+@click.pass_context
+def add_data(ctx):
+    """Add json-format data to db. Multiple keys can be added"""
+    cl = ctx.obj["RedisClient"]
+    new_doc = {"key1": "value1", "key2": "value2"}
+    edited_doc = click.edit(json.dumps(new_doc, indent=4), **js_edit_opts)
+    if edited_doc:
+        try:
+            multiple_add(cl, edited_doc)
+        except Exception as ex:
+            print("Key was not added: ", ex)
+
+
+@cli.command()
+@click.argument("key")
 @click.pass_context
 def edit_doc(ctx, key):
-    """Open document in editor. Support only json-format"""
+    """Open document in editor. Support only json-format.
+
+    KEY: key of the document"""
     cl = ctx.obj["RedisClient"]
-    st = False
-    zst = False
     if cl.type(key) == b"string":
+        key_type = 'string'
         try:
             new_doc = {key: cl.get(key).decode("utf-8")}
         except UnicodeDecodeError:
             raise click.ClickException("HyperLogLog cant be edited")
     elif cl.type(key) == b"list":
+        key_type = 'list'
         new_doc = bytes_to_string({key.encode("utf-8"): cl.lrange(key, 0, -1)})
     elif cl.type(key) == b"set":
-        st = True
+        key_type = 'set'
         new_doc = bytes_to_string({key.encode("utf-8"): cl.smembers(key)})
     elif cl.type(key) == b"hash":
+        key_type = 'hash'
         new_doc = bytes_to_string({key.encode("utf-8"): cl.hgetall(key)})
     elif cl.type(key) == b"zset":
-        zst = True
+        key_type = 'zset'
         new_doc = bytes_to_string(
             {key.encode("utf-8"): cl.zrange(key, 0, -1, withscores=True)}
         )
@@ -230,25 +232,28 @@ def edit_doc(ctx, key):
         json.dumps(new_doc, indent=4), require_save=True, extension=".js"
     )
     if edited_doc:
-        cl.delete(key)
         try:
-            add_json_to_redis(cl, edited_doc, st=st, zst=zst)
+            new_key = [*json.loads(edited_doc).keys()]
+            if len(new_key) != 1:
+                raise click.ClickException('Only one key can be edited at a time')
+            cl.delete(key)
+            add_any_key_type(cl, json.dumps(json.loads(edited_doc)[new_key[0]]), key_type, new_key[0])
         except Exception as ex:
             print("Key was not edited: ", ex)
-            add_json_to_redis(cl, json.dumps(new_doc), st=st, zst=zst)
+            add_any_key_type(cl, json.dumps(new_doc[key]), key_type, key)
 
 
 @cli.command()
-@click.option("-k", "key", help="Document key.")
+@click.argument("key")
 @click.pass_context
-def del_doc(ctx, key):
+def del_key(ctx, key):
     """Delete key from db"""
     cl = ctx.obj["RedisClient"]
     cl.delete(key)
 
 
 @cli.command()
-@click.option("-k", "key", help="Document key.")
+@click.argument("key")
 @click.pass_context
 def to_set(ctx, key):
     """Turn redis list to set"""
@@ -264,15 +269,19 @@ def to_set(ctx, key):
 
 
 @cli.command()
-@click.option("-k", "key", help="Document key.")
+@click.argument("key")
 @click.pass_context
 def to_zset(ctx, key):
     """Turn redis hash into sorted set"""
     cl = ctx.obj["RedisClient"]
     if cl.type(key) == b"hash":
         data = cl.hgetall(key)
-        cl.delete(key)
-        cl.zadd(key, data)
+        try:
+            cl.delete(key)
+            cl.zadd(key, data)
+        except Exception:
+            cl.hmset(key, data)
+            print(f'Wrong value in key: {data}')
     else:
         raise click.ClickException(
             f'Wrong key type: "{cl.type(key)}". Argument should be b"hash"'
